@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package Graphics::GVG::AST::Circle;
-$Graphics::GVG::AST::Circle::VERSION = '0.3';
+$Graphics::GVG::AST::Circle::VERSION = '0.4';
 use strict;
 use warnings;
 use Moose;
@@ -42,6 +42,16 @@ has color => (
     default => 0,
 );
 
+sub to_string
+{
+    my ($self) = @_;
+    my $str = 'circle( #'
+        . sprintf( '%08x', $self->color )
+        . ', ' . join( ', ', $self->cx, $self->cy, $self->r )
+        . " );\n";
+    return $str;
+}
+
 
 no Moose;
 __PACKAGE__->meta->make_immutable;
