@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package Graphics::GVG::AST::Glow;
-$Graphics::GVG::AST::Glow::VERSION = '0.3';
+$Graphics::GVG::AST::Glow::VERSION = '0.4';
 use strict;
 use warnings;
 use Moose;
@@ -32,6 +32,18 @@ use Graphics::GVG::AST::Effect;
 with 'Graphics::GVG::AST::Effect';
 
 
+sub to_string
+{
+    my ($self) = @_;
+    my @commands = @{ $self->commands };
+
+    my $str = "glow {\n";
+    $str .= join( "", map { $_->to_string } @commands );
+    $str .= "}\n";
+
+    return $str;
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
