@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package Graphics::GVG::AST::Polygon;
-$Graphics::GVG::AST::Polygon::VERSION = '0.3';
+$Graphics::GVG::AST::Polygon::VERSION = '0.4';
 use strict;
 use warnings;
 use Moose;
@@ -72,6 +72,18 @@ sub BUILDARGS
 }
 
 
+sub to_string
+{
+    my ($self) = @_;
+    my $str = 'poly( #'
+        . sprintf( '%08x', $self->color )
+        . ', ' . join( ', ', $self->cx, $self->cy, $self->r, $self->sides,
+            $self->rotate )
+        . " );\n";
+    return $str;
+}
+
+
 sub _calc_x_coord
 {
     my ($class, $side, $total_sides, $radius, $rotate, $cx) = @_;
