@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package Graphics::GVG::AST::Rect;
-$Graphics::GVG::AST::Rect::VERSION = '0.3';
+$Graphics::GVG::AST::Rect::VERSION = '0.4';
 use strict;
 use warnings;
 use Moose;
@@ -43,6 +43,16 @@ has color => (
     default => 0,
 );
 
+sub to_string
+{
+    my ($self) = @_;
+    my $str = 'rect( #'
+        . sprintf( '%08x', $self->color )
+        . ', ' . join( ', ', $self->x, $self->y, $self->width, $self->height )
+        . " );\n";
+    return $str;
+}
+
 
 no Moose;
 __PACKAGE__->meta->make_immutable;
